@@ -14,10 +14,10 @@ from neco.llm.rag.naive_rag.pgvector.pgvector_rag import PgvectorRag
 from neco.llm.tools.tools_loader import ToolsLoader
 from pydantic import BaseModel
 from langchain_mcp_adapters.client import MultiServerMCPClient
-from langgraph.prebuilt import ToolNode
+from langgraph.prebuilt import ToolNode, create_react_agent
 from langgraph.graph import StateGraph
 from langgraph.constants import END
-from langchain_core.messages import AIMessage, BaseMessage, ToolMessage
+from langchain_core.messages import AIMessage, BaseMessage, ToolMessage, SystemMessage
 
 class BasicNode:
         
@@ -89,7 +89,7 @@ class BasicNode:
             rag_search_request.search_query = config["configurable"]["graph_request"].graph_user_message
 
             if len(selected_knowledge_ids) != 0 and rag_search_request.index_name not in selected_knowledge_ids:
-                logger.info(
+                logger.debug(
                     f"智能知识路由判断:[{rag_search_request.index_name}]不适合当前问题,跳过检索")
                 continue
             
@@ -116,7 +116,7 @@ class BasicNode:
         rag_message = TemplateLoader.render_template(
             'prompts/graph/naive_rag_node_prompt', template_data)
 
-        logger.info(f"RAG增强Prompt: {rag_message}")
+        logger.debug(f"RAG增强Prompt已生成，长度: {len(rag_message)}")
         state["messages"].append(HumanMessage(content=rag_message))
         return state
 
@@ -170,7 +170,7 @@ class BasicNode:
         rag_search_request.graph_rag_request.search_query = rag_search_request.search_query
         graph_result = await graphiti.search(req=rag_search_request.graph_rag_request)
 
-        logger.info(
+        logger.debug(
             f"GraphRAG模式检索知识库: {rag_search_request.graph_rag_request.group_ids}, "
             f"结果数量: {len(graph_result)}"
         )
@@ -429,30 +429,31 @@ class ToolsNodes(BasicNode):
         self.tools_prompt_tokens = 0
         self.tools_completions_tokens = 0
 
-    async def call_with_structured_output(self, llm, prompt, pydantic_model,
-                                          messages: Union[Dict, List], max_retries: int = 3):
+    async def call_with_structured_output(self, llm, user_message: str, pydantic_model):
         """
         通用结构化输出调用方法
 
         Args:
             llm: LangChain LLM实例
-            prompt: LangChain prompt模板
+            user_message: 用户消息内容
             pydantic_model: 目标Pydantic模型类
-            messages: 消息内容 (dict或list格式)
-            max_retries: 最大重试次数
 
         Returns:
             解析后的Pydantic模型实例
         """
-        parser = StructuredOutputParser(llm, max_retries=max_retries)
-        return await parser.parse_with_structured_output(prompt, messages, pydantic_model)
+        parser = StructuredOutputParser(llm)
+        return await parser.parse_with_structured_output(user_message, pydantic_model)
 
     async def setup(self, request: BaseModel):
         """初始化工具节点"""
+        # 初始化LLM客户端和结构化输出解析器
+        self.llm = self.get_llm_client(request)
+        self.structured_output_parser = StructuredOutputParser(self.llm)
+        
         # 初始化MCP客户端配置
-        logger.info({len(request.tools_servers)})
+        logger.debug(f"工具服务器数量: {len(request.tools_servers)}")
         for server in request.tools_servers:
-            logger.info(f"Tools Server: {server}")
+            logger.debug(f"Tools Server: {server}")
             if server.url.startswith("langchain:"):
                 continue
 
@@ -476,7 +477,7 @@ class ToolsNodes(BasicNode):
         # 初始化LangChain工具
         for server in request.tools_servers:
             if server.url.startswith("langchain:"):
-                langchain_tools = ToolsLoader.load_tools(server.url, server.extra_prompt, server.extra_param_prompt)
+                langchain_tools = ToolsLoader.load_tools(server.url, server.extra_tools_prompt, server.extra_param_prompt)
                 self.tools.extend(langchain_tools)
 
     async def build_tools_node(self) -> ToolNode:
@@ -484,124 +485,132 @@ class ToolsNodes(BasicNode):
         try:
             if self.tools:
                 tool_node = ToolNode(self.tools, handle_tool_errors=True)
-                logger.info(f"成功构建工具节点，包含 {len(self.tools)} 个工具")
+                logger.debug(f"成功构建工具节点，包含 {len(self.tools)} 个工具")
                 return tool_node
             else:
-                logger.info("未找到可用工具，返回空工具节点")
+                logger.debug("未找到可用工具，返回空工具节点")
                 return ToolNode([])
         except Exception as e:
             logger.error(f"构建工具节点失败: {e}")
             return ToolNode([])
 
-    # ========== 简化的 ReAct 节点组合构建器 ==========
+    # ========== 使用 LangGraph 标准 ReAct Agent 实现 ==========
 
-    def build_react_nodes(self,
+    async def build_react_nodes(self,
                           graph_builder: StateGraph,
                           composite_node_name: str = "react_agent",
-                          system_prompt: Optional[str] = None,
-                          end_node: str = END,
-                          tools_node: Optional[ToolNode] = None,
-                          max_iterations: int = 10) -> str:
+                          additional_system_prompt: Optional[str] = None,
+                          next_node: str = END,
+                          tools_node: Optional[ToolNode] = None) -> str:
         """
-        构建独立闭环的 ReAct Agent 组合节点
-
-        这是一个可复用的组合节点，Agent 负责执行工具，有解决方案就结束，
-        没有解决方案就继续循环，直到达到最大迭代次数。
+        构建 ReAct Agent 节点，直接使用 LangGraph 的 create_react_agent
 
         Args:
             graph_builder: StateGraph 构建器
-            composite_node_name: 组合节点名称
-            system_prompt: 系统提示
-            end_node: 结束节点  
-            tools_node: 外部工具节点
-            max_iterations: 最大迭代次数
+            composite_node_name: 组合节点名称前缀
+            additional_system_prompt: 追加的系统提示（会与基础提示合并）
+            next_node: ReAct Agent 完成后的下一个节点
+            tools_node: 外部工具节点，如果提供则优先使用
 
         Returns:
-            str: 组合节点的出口节点名称
+            str: ReAct 节点的入口节点名称
         """
-        # 内部节点名称
-        llm_node_name = f"{composite_node_name}_llm"
-        tool_node_name = f"{composite_node_name}_tools"
-
-        # 添加 LLM 节点
-        async def llm_node(state: Dict[str, Any], config: RunnableConfig) -> Dict[str, Any]:
+        # 创建包装节点名称
+        react_wrapper_name = f"{composite_node_name}_wrapper"
+        
+        async def react_wrapper_node(state: Dict[str, Any], config: RunnableConfig) -> Dict[str, Any]:
+            """ReAct Agent 包装节点 - 使用 LangGraph 标准实现"""
             try:
-                messages = state["messages"]
                 graph_request = config["configurable"]["graph_request"]
-
-                # 获取 LLM 并绑定工具
-                llm = self.get_llm_client(graph_request).bind_tools(self.tools)
-
-                # 构建提示 - 使用现有的模板系统
-                if system_prompt:
-                    # 使用传入的自定义系统提示
-                    prompt = ChatPromptTemplate.from_messages([
-                        ("system", system_prompt),
-                        MessagesPlaceholder(variable_name="messages"),
-                    ])
+                
+                # 获取 LLM 客户端
+                llm = self.get_llm_client(graph_request)
+                
+                # 构建完整的系统提示（基础 + 追加）
+                base_system_prompt = self._build_base_react_system_prompt(graph_request)
+                
+                if additional_system_prompt:
+                    final_system_prompt = f"{base_system_prompt}\n\n{additional_system_prompt}"
                 else:
-                    # 使用专门的ReAct Agent模板系统
-                    from neco.core.utils.template_loader import TemplateLoader
-                    system_message_prompt = TemplateLoader.render_template(
-                        'prompts/graph/react_agent_system_message', {
-                            "user_system_message": getattr(graph_request, 'system_message_prompt', "你是一个智能助手，能够使用工具来帮助解决问题。请仔细分析问题，按照ReAct模式工作：先获取必要信息（如当前时间），然后使用合适的工具，最后提供完整的解答。")
-                        })
-                    prompt = ChatPromptTemplate.from_messages([
-                        ("system", system_message_prompt),
-                        MessagesPlaceholder(variable_name="messages"),
-                    ])
-
-                # 调用 LLM
-                response = await (prompt | llm).ainvoke({"messages": messages})
-
-                # 更新迭代计数
-                current_iteration = state.get("react_iteration", 0) + 1
-                return {
-                    "messages": [response],
-                    "react_iteration": current_iteration
-                }
-
+                    final_system_prompt = base_system_prompt
+                
+                # 获取当前工具
+                current_tools = self._get_current_tools(tools_node)
+                
+                # 使用 LangGraph 标准的 create_react_agent
+                react_agent = create_react_agent(
+                    model=llm,
+                    tools=current_tools,
+                    prompt=SystemMessage(content=final_system_prompt),
+                    checkpointer=None,  # 不使用检查点
+                    debug=False
+                )
+                
+                self.log(config, f"ReAct Agent 开始处理，工具数量: {len(current_tools)}")
+                
+                # 调用标准的 ReAct Agent
+                result = await react_agent.ainvoke(
+                    {"messages": state["messages"]},
+                    config=config
+                )
+                
+                # 提取最后的 AI 消息作为结果
+                final_messages = result.get("messages", [])
+                if final_messages:
+                    # 找到最后一个 AI 消息
+                    last_ai_message = None
+                    for msg in reversed(final_messages):
+                        if isinstance(msg, AIMessage):
+                            last_ai_message = msg
+                            break
+                    
+                    if last_ai_message:
+                        self.log(config, "ReAct Agent 处理完成")
+                        return {"messages": last_ai_message}
+                    else:
+                        return {"messages": AIMessage(content="ReAct Agent 未产生有效的 AI 响应")}
+                else:
+                    return {"messages": AIMessage(content="ReAct Agent 未返回任何消息")}
+                    
             except Exception as e:
-                logger.error(f"ReAct LLM 节点失败: {e}")
-                return {"messages": [AIMessage(content=f"处理失败: {str(e)}")]}
+                logger.error(f"ReAct Agent 处理失败: {e}")
+                return {"messages": AIMessage(content=f"ReAct Agent 处理失败: {str(e)}")}
+        
+        # 将包装节点添加到图中
+        graph_builder.add_node(react_wrapper_name, react_wrapper_node)
+        
+        logger.debug(f"ReAct 节点构建完成: {react_wrapper_name}")
+        
+        return react_wrapper_name
+    
+    def _build_base_react_system_prompt(self, graph_request) -> str:
+        """构建基础的 ReAct 系统提示"""
+        try:
+            # 使用模板系统生成基础系统提示
+            base_prompt = TemplateLoader.render_template(
+                'prompts/graph/react_agent_system_message', {
+                    "user_system_message": getattr(graph_request, 'system_message_prompt', 
+                                                 "你是一个智能助手，能够使用工具来帮助解决问题。")
+                })
+            return base_prompt
+        except Exception as e:
+            logger.warning(f"加载 ReAct 系统提示模板失败: {e}，使用默认提示")
+            return """你是一个智能助手，能够使用工具来帮助解决问题。
 
-        graph_builder.add_node(llm_node_name, llm_node)
+请按照 ReAct (Reasoning and Acting) 模式工作：
+1. **Thought**: 仔细分析用户的问题，思考需要哪些信息或工具
+2. **Action**: 选择合适的工具并调用
+3. **Observation**: 观察工具的返回结果
+4. **Thought**: 基于结果继续思考，决定是否需要更多工具或可以给出最终答案
 
-        # 添加工具节点
-        async def tool_node(state: Dict[str, Any], config: RunnableConfig) -> Dict[str, Any]:
-            try:
-                current_tools_node = tools_node or await self.build_tools_node()
-                return await current_tools_node.ainvoke(state)
-            except Exception as e:
-                logger.error(f"ReAct 工具节点失败: {e}")
-                return {"messages": [ToolMessage(content=f"工具执行失败: {str(e)}", tool_call_id="error")]}
-
-        graph_builder.add_node(tool_node_name, tool_node)
-
-        # 条件判断函数 - 决定是否继续循环或结束
-        def should_continue(state: Dict[str, Any]) -> Literal["tools", "end"]:
-            messages = state.get("messages", [])
-            current_iteration = state.get("react_iteration", 0)
-
-            # 检查是否达到最大迭代次数
-            if current_iteration >= max_iterations:
-                logger.warning(f"ReAct Agent 达到最大迭代次数 {max_iterations}，强制结束")
-                return "end"
-
-            # 检查最后一条消息是否有工具调用
-            if messages and hasattr(messages[-1], 'tool_calls') and messages[-1].tool_calls:
-                return "tools"
-
-            # 没有工具调用，表示 Agent 认为已经有了解决方案
-            return "end"
-
-        # 添加条件边和回环边
-        graph_builder.add_conditional_edges(
-            llm_node_name,
-            should_continue,
-            {"tools": tool_node_name, "end": end_node}
-        )
-        # 工具执行后回到 LLM 继续思考
-        graph_builder.add_edge(tool_node_name, llm_node_name)
-
-        return llm_node_name  # 返回组合节点的入口节点
+重要规则：
+- 始终先思考再行动
+- 如果需要当前时间等实时信息，请使用相应的工具获取
+- 提供完整、准确的答案
+- 如果遇到错误，请解释并尝试其他方法"""
+    
+    def _get_current_tools(self, tools_node: Optional[ToolNode]) -> list:
+        """获取当前可用的工具列表"""
+        if tools_node and hasattr(tools_node, 'tools'):
+            return tools_node.tools
+        return self.tools
